@@ -48,9 +48,9 @@ from libs.version import __version__
 from libs.hashableQListWidgetItem import HashableQListWidgetItem
 from predict import detectStoma
 from predict.generateExcel import generaExcel
-import notebooks.notebookmenu
+#import notebooks.notebookmenu
 import notebooks.notebookYolo
-import notebooks.mainModel
+#import notebooks.mainModel
 import predict.selectPesos
 import libs.resources
 __appname__ = 'labelStoma'
@@ -1434,17 +1434,17 @@ class MainWindow(QMainWindow, WindowMixin):
 
             else:#if it is not by default
                 path = os.path.dirname(ustr(self.filePath)) if self.filePath else '.'
-                model = notebooks.mainModel.selectModel(self, True)
-                if model is not None:
-                    box = QDialog()
-                    box.setWindowFlags(box.windowFlags() | QtCore.Qt.CustomizeWindowHint)
-                    box.setWindowFlags(box.windowFlags() & ~QtCore.Qt.WindowCloseButtonHint)
-                    box.setWindowFlag(QtCore.Qt.WindowCloseButtonHint, False)
-                    box.resize(179, 1)
-                    box.setWindowTitle("Processing...")
-                    box.show()
-                    model.predict(path, path, float(ui.le_1))
-                    box.close()
+                #model = notebooks.mainModel.selectModel(self, True)
+                #if model is not None:
+                #    box = QDialog()
+                #    box.setWindowFlags(box.windowFlags() | QtCore.Qt.CustomizeWindowHint)
+                #    box.setWindowFlags(box.windowFlags() & ~QtCore.Qt.WindowCloseButtonHint)
+                #    box.setWindowFlag(QtCore.Qt.WindowCloseButtonHint, False)
+                #    box.resize(179, 1)
+                #    box.setWindowTitle("Processing...")
+                #    box.show()
+                #    model.predict(path, path, float(ui.le_1))
+                #    box.close()
                 self.defaultSaveDir = path
                 self.importDirImages(path)
 
